@@ -38,15 +38,15 @@ G-Core API Token is recommended authentication option.
 The token needed by Certbot for add temporary TXT record to zone what you need certificates for.
 
 .. code-block:: ini
-   :name: gcore_token.ini
-   :caption: Example credentials file using restricted API Token (recommended):
+   :name: token
+   :caption: Example `gcore.ini` file using restricted API Token (recommended):
 
    # G-Core API token used by Certbot
    dns_gcore_apitoken = 0123456789abcdef0123456789abcdef01234567
 
 .. code-block:: ini
-   :name: gcore_ayth.ini
-   :caption: Example credentials file using authentication credentials (not recommended):
+   :name: auth
+   :caption: Example `gcore.ini` file using authentication credentials (not recommended):
 
    # G-Core API credentials used by Certbot
    dns_gcore_email = gcore_user@example.com
@@ -71,6 +71,15 @@ file. This warning will be emitted each time Certbot uses the credentials file,
 including for renewal, and cannot be silenced except by addressing the issue
 (e.g., by using a command like ``chmod 600`` to restrict access to the file).
 
+Also you can specify the G-Core ``auth`` and ``dns`` urls.
+
+.. code-block:: ini
+   :name: urls
+   :caption: Example `gcore.ini` file using alternative `auth` and `dns` urls.
+
+    # G-Core API credentials used by Certbot
+    dns_gcore_auth_url = https://auth.example.com
+    dns_gcore_api_url = https://dns_api.example.com
 
 Examples
 --------
